@@ -24,6 +24,7 @@
 
 #include "utils.h"
 #include "kcalprefs.h"
+#include "helper_p.h"
 
 #include <Collection>
 #include <CollectionDialog>
@@ -107,7 +108,7 @@ KCalCore::Event::Ptr CalendarSupport::event(const KCalCore::Incidence::Ptr &inci
 KCalCore::Incidence::List CalendarSupport::incidencesFromItems(const Akonadi::Item::List &items)
 {
     KCalCore::Incidence::List incidences;
-    Q_FOREACH (const Akonadi::Item &item, items) {
+    for (const Akonadi::Item &item : items) {
         if (const KCalCore::Incidence::Ptr e = CalendarSupport::incidence(item)) {
             incidences.push_back(e);
         }
@@ -196,14 +197,14 @@ QMimeData *CalendarSupport::createMimeData(const Akonadi::Item::List &items,
         const KDateTime::Spec &timeSpec)
 {
     if (items.isEmpty()) {
-        return 0;
+        return nullptr;
     }
 
     KCalCore::MemoryCalendar::Ptr cal(new KCalCore::MemoryCalendar(timeSpec));
 
     QList<QUrl> urls;
     int incidencesFound = 0;
-    Q_FOREACH (const Akonadi::Item &item, items) {
+    for (const Akonadi::Item &item : items) {
         const KCalCore::Incidence::Ptr incidence(CalendarSupport::incidence(item));
         if (!incidence) {
             continue;
@@ -215,7 +216,7 @@ QMimeData *CalendarSupport::createMimeData(const Akonadi::Item::List &items,
     }
 
     if (incidencesFound == 0) {
-        return 0;
+        return nullptr;
     }
 
     std::unique_ptr<QMimeData> mimeData(new QMimeData);
@@ -249,7 +250,7 @@ static QByteArray findMostCommonType(const Akonadi::Item::List &items)
         return "Incidence";
     }
 
-    Q_FOREACH (const Akonadi::Item &item, items) {
+    for (const Akonadi::Item &item : items) {
         if (!CalendarSupport::hasIncidence(item)) {
             continue;
         }
@@ -342,7 +343,8 @@ bool CalendarSupport::canDecode(const QMimeData *md)
 QList<QUrl> CalendarSupport::incidenceItemUrls(const QMimeData *mimeData)
 {
     QList<QUrl> urls;
-    Q_FOREACH (const QUrl &i, mimeData->urls()) {
+    const QList<QUrl> urlsList = mimeData->urls();
+    for (const QUrl &i : urlsList ) {
         if (isValidIncidenceItemUrl(i)) {
             urls.push_back(i);
         }
@@ -354,7 +356,8 @@ QList<QUrl> CalendarSupport::todoItemUrls(const QMimeData *mimeData)
 {
     QList<QUrl> urls;
 
-    Q_FOREACH (const QUrl &i, mimeData->urls()) {
+    const QList<QUrl> urlList = mimeData->urls();
+    for (const QUrl &i : urlList) {
         if (isValidIncidenceItemUrl(i, QStringList() << KCalCore::Todo::todoMimeType())) {
             urls.push_back(i);
         }
@@ -378,7 +381,7 @@ KCalCore::Todo::List CalendarSupport::todos(const QMimeData *mimeData,
     if (cal) {
         const KCalCore::Todo::List calTodos = cal->todos();
         todos.reserve(calTodos.count());
-        Q_FOREACH (const KCalCore::Todo::Ptr &i, calTodos) {
+        for (const KCalCore::Todo::Ptr &i : calTodos) {
             todos.push_back(KCalCore::Todo::Ptr(i->clone()));
         }
     }
@@ -395,9 +398,9 @@ KCalCore::Incidence::List CalendarSupport::incidences(const QMimeData *mimeData,
 #ifndef QT_NO_DRAGANDDROP
     KCalCore::Calendar::Ptr cal(KCalUtils::DndFactory::createDropCalendar(mimeData, spec));
     if (cal) {
-        KCalCore::Incidence::List calIncidences = cal->incidences();
+        const KCalCore::Incidence::List calIncidences = cal->incidences();
         incidences.reserve(calIncidences.count());
-        Q_FOREACH (const KCalCore::Incidence::Ptr &i, calIncidences) {
+        for (const KCalCore::Incidence::Ptr &i : calIncidences) {
             incidences.push_back(KCalCore::Incidence::Ptr(i->clone()));
         }
     }
@@ -506,7 +509,7 @@ Akonadi::Collection::List CalendarSupport::collectionsFromIndexes(const QModelIn
 {
     Akonadi::Collection::List l;
     l.reserve(indexes.count());
-    Q_FOREACH (const QModelIndex &idx, indexes) {
+    for (const QModelIndex &idx : indexes) {
         l.push_back(collectionFromIndex(idx));
     }
     return l;
@@ -610,7 +613,7 @@ QString CalendarSupport::displayName(Akonadi::ETMCalendar *calendar, const Akona
         const QString nameStr = c.displayName(); // folder name: can be anything
 
         QString typeStr;
-        const QString mimeStr = c.contentMimeTypes().join(QStringLiteral(","));
+        const QString mimeStr = c.contentMimeTypes().join(QLatin1Char(','));
         if (mimeStr.contains(QStringLiteral(".event"))) {
             typeStr = i18n("Calendar");
         } else if (mimeStr.contains(QStringLiteral(".todo"))) {
@@ -746,7 +749,7 @@ void CalendarSupport::saveAttachments(const Akonadi::Item &item, QWidget *parent
         targetDir = QFileInfo(targetFile).absolutePath() + QLatin1Char('/');
     }
 
-    Q_FOREACH (const Attachment::Ptr &attachment, attachments) {
+    for (const Attachment::Ptr &attachment : qAsConst(attachments)) {
         targetFile = targetDir + attachment->label();
         QUrl sourceUrl;
         if (attachment->isUri()) {
@@ -767,10 +770,11 @@ QStringList CalendarSupport::categories(const KCalCore::Incidence::List &inciden
     QStringList cats, thisCats;
     // @TODO: For now just iterate over all incidences. In the future,
     // the list of categories should be built when reading the file.
-    Q_FOREACH (const KCalCore::Incidence::Ptr &incidence, incidences) {
+    for (const KCalCore::Incidence::Ptr &incidence : incidences) {
         thisCats = incidence->categories();
+        const QStringList::ConstIterator send(thisCats.constEnd());
         for (QStringList::ConstIterator si = thisCats.constBegin();
-                si != thisCats.constEnd(); ++si) {
+                si != send; ++si) {
             if (!cats.contains(*si)) {
                 cats.append(*si);
             }
